@@ -17,11 +17,14 @@
 #' }
 #' @export
 
+
+
 HexagonsClus<-function(Centroids,Cluster,BCentr,Coord,Row,Col,colSeq=rainbow(nrow(Centroids)))
 {  Vector<-Cluster;
    Colors<-ClusCol(Centroids,Vector,colSeq=colSeq);
+   opar <- par(mar=c(1,1,1,1),pty="m",xpd=TRUE,family="serif");
    Hexagons(Coord,Row, Col,color = NA, border = NA)
    for (i in c(1:nrow(Coord))) {Hexa(Coord$X[i],Coord$Y[i],color=Colors[i],border="gray")}
    text(Coord[BCentr,"X"],Coord[BCentr,"Y"],c(1:nrow(Centroids)),cex=1,font=2,col="black")
-}
-
+   on.exit(par(opar))
+}
\ No newline at end of file
